package com.persagy.dmp.rwd.define.service;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.persagy.dmp.basic.model.QueryCriteria;
import com.persagy.dmp.define.entity.ObjectInfoDefine;
import com.persagy.dmp.define.entity.ObjectTypeDefine;

import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 信息点 接口
 * @author Charlie Yu
 * @date 2021-06-25
 */
public interface IObjectInfoService {

    /**
     * 通过主键查询
     * @param id
     * @return
     */
    ObjectInfoDefine load(String id);

    /**
     * 通过多主键查询
     * @param idList
     * @return
     */
    List<ObjectInfoDefine> queryByIds(List<String> idList);

    /**
     * 通过对象类型编码查询
     * @param typeCode
     * @return
     */
    List<ObjectInfoDefine> queryByType(String typeCode);

    /**
     * 通过多对象类型编码查询
     * @param typeCodeList
     * @return Map<typeCode, Map<InfoCode, ObjectInfo>>
     */
    Map<String, Map<String, ObjectInfoDefine>> queryByTypes(List<String> typeCodeList);

    /**
     * 按条件计数
     * @param queryWrapper 查询条件
     * @return 结果数量
     */
    Integer queryCount(Wrapper<ObjectInfoDefine> queryWrapper);

    /**
     * 按条件查询
     * @param queryWrapper 查询条件
     * @return 列表
     */
    List<ObjectInfoDefine> queryByCondition(Wrapper<ObjectInfoDefine> queryWrapper);

    /**
     * 按条件查询
     * @param page 分页条件
     * @param queryWrapper 查询条件
     * @return 分页结果
     */
    Page<ObjectInfoDefine> queryByCondition(Page<ObjectInfoDefine> page, Wrapper<ObjectInfoDefine> queryWrapper);

    /**
     * 新增
     * @param voList 待新增数据
     * @return 新增后数据
     */
    List<ObjectInfoDefine> insert(List<ObjectInfoDefine> voList);

    /**
     * 修改
     * @param voList 待修改数据
     * @return 修改后数据
     */
    List<ObjectInfoDefine> update(List<ObjectInfoDefine> voList);

    /**
     * 删除
     * @param idList 主键
     */
    void delete(List<String> idList);
    /***
     * Description: 根据筛选条件和对象类型编码查询信息点数据
     * @param wrapper : 筛选条件
     * @param classCodes : 对象类型编码集合
     * @return : java.util.List<com.persagy.dmp.define.entity.ObjectInfoDefine>
     * @author : lijie
     * @date :2021/10/28 14:51
     * Update By lijie 2021/10/28 14:51
     */
    List<ObjectInfoDefine> queryByClassCodes(QueryWrapper<ObjectInfoDefine> wrapper, Set<String> classCodes);
}
